@@ -1,14 +1,14 @@
 /*
  * cmpiOSBase_ProcessorProvider.c
  *
- * (C) Copyright IBM Corp. 2002
+ * (C) Copyright IBM Corp. 2002, 2009
  *
- * THIS FILE IS PROVIDED UNDER THE TERMS OF THE COMMON PUBLIC LICENSE 
+ * THIS FILE IS PROVIDED UNDER THE TERMS OF THE ECLIPSE PUBLIC LICENSE 
  * ("AGREEMENT"). ANY USE, REPRODUCTION OR DISTRIBUTION OF THIS FILE 
  * CONSTITUTES RECIPIENTS ACCEPTANCE OF THE AGREEMENT.
  *
- * You can obtain a current copy of the Common Public License from
- * http://www.opensource.org/licenses/cpl1.0.txt
+ * You can obtain a current copy of the Eclipse Public License from
+ * http://www.opensource.org/licenses/eclipse-1.0.php
  *
  * Author:       Heidi Neumann <heidineu@de.ibm.com>
  * Contributors:
@@ -30,6 +30,7 @@
 #include "OSBase_Common.h"
 #include "cmpiOSBase_Common.h"
 #include "cmpiOSBase_Processor.h"
+#include "OSBase_Processor.h"
 
 static const CMPIBroker * _broker;
 
@@ -51,6 +52,7 @@ static const CMPIBroker * _broker;
 CMPIStatus OSBase_ProcessorProviderCleanup( CMPIInstanceMI * mi, 
            const CMPIContext * ctx, CMPIBoolean terminate) { 
   _OSBASE_TRACE(1,("--- %s CMPI Cleanup() called",_ClassName));
+  proc_cancel_thread();
   _OSBASE_TRACE(1,("--- %s CMPI Cleanup() exited",_ClassName));
   CMReturn(CMPI_RC_OK);
 }
